===================================
Detailed User Interface Information
===================================

Binary
------
The main module in `gwent` is the binary module which contains all of the
needed methods for ...

.. automodule:: gwent.binary
    :members:
    :inherited-members:

Detector
--------
The `gwent.detector` module contains the methods necessary for ...

.. automodule:: gwent.detector
    :members:
    :inherited-members:

SNR
---
.. automodule:: gwent.snr
    :members:
    :inherited-members:

SNRPlot
-------
.. automodule:: gwent.snrplot
    :members:
    :inherited-members:

Waveform
--------
.. automodule:: gwent.waveform
    :members:
    :inherited-members:

Utils
-----
.. automodule:: gwent.utils
    :members:
    :inherited-members:
